from setuptools import setup

setup(
    name='json_placeholder_client',
    version='1.0.0',
    description='Client for JSON-Placeholder',
    install_requires=['requests'],
    packages=['json_placeholder']
)
